// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 2001 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************

package com.ibm.etools.cobol.importer;


import java.util.*;

/**
 *   The parser instantiates an object of this class each time it encounters a
 *   group item in the COMMAREA field of the CICS transaction.
 */

public class CobolGroupRecord extends CobolRecord
{
	private static String copyright = "(c) Copyright IBM Corporation 1998, 1999.";
   CobolGroupRecord(CobolRecord owner, String name, int level)
   {
	  super(owner, name, level);
   }   
   void add(CobolRecord record)
   {
	  list_.addElement(record);
   }   
   String alignment()
   {
	  if (alignment_)
		 return "ALIGN";
	  else
		 return " ";
   }   
   int sign()
   {
	  return sign_;
   }   
void trace()
{
	CobolResource.display("Group:           " + name_);
	CobolResource.display("alignment:       " + alignment_);
	CobolResource.display("usage:           " + usage_);
	CobolResource.display("sign:            " + sign_);
	CobolResource.display("bound:           " + arrayBound_);
	CobolResource.display("cobolType:       " + cobolType());
   
	for (int i=0; i<list_.size(); i++) 
	{
		if (list_.elementAt(i) instanceof CobolGroupRecord)
			((CobolGroupRecord)list_.elementAt(i)).trace();
		else if (list_.elementAt(i) instanceof CobolElementaryRecord)
			((CobolElementaryRecord)list_.elementAt(i)).trace();
	}

	CobolResource.display("end group:       " + name_);
}
   int usage()
   {
	  return usage_;
   }   
/**
 * Stores information in the tree that is needed for DRT creation.
 * Creation date: 
 * @param aNonRedefineList Vector - nodes of the tree that don't contain REDEFINE statements
 * @param aNonDependingList Vector - nodes of the tree that don't contain ODO statements
 * @param qualifiedName Vector
 * @param nestedODO boolean - true if this node of the tree is inside an ODO
 */
 void walkTree(Vector aNonRedefineList, Vector aNonDependingList, Vector qualifiedName, boolean nestedODO) throws CobolException
{

	/*
	 * If the parent is synchronized,
	 * this group also is synchronized
	 */
	if(((CobolGroupRecord)owner()).alignment() == "ALIGN") {
		alignment_ = true;
	}	 

	Vector names = new Vector();
	int nameGen=0;
	// Find and change any duplicate names
	for (int i=0;i<list_.size();i++)
	{
		CobolRecord rec = (CobolRecord) list_.elementAt(i);
		String recName = rec.name().toLowerCase();
		if (names.contains(recName))
		{
			rec.name_ = recName+"_"+nameGen;
			nameGen++;
			Object[] obj = {name(), recName, rec.name() };
			CobolResource.display(CobolResource.getString("_EXC_Two_records_have_same_name", obj));
		}else{
			names.addElement(rec.name().toLowerCase());
		}
	}
			
	// Sets the fully qualified name
	if (nestedODO)
	{
		qualifiedName.addElement("0");
	}
	qualifiedName.addElement(name_);
	qualifiedName_ = new String[qualifiedName.size()];
	qualifiedName.copyInto(qualifiedName_);

	// Sets the nested ODO flag
	boolean nestODO;
	if (dependedOnItem_.size() > 0)
	{
		nestODO=true;
	}
	else
	{
		nestODO=false;
	}
	
	// Recurse through the entire tree structure containing group and
	// elementary items
	for (int i=0; i<list_.size(); i++)
	{

//	System.out.println("add record: " + ((Record)list_.elementAt(i)).name());
		if (list_.elementAt(i) instanceof CobolGroupRecord)
		{
			CobolGroupRecord type = (CobolGroupRecord)list_.elementAt(i);
			type.walkTree(aNonRedefineList, aNonDependingList, qualifiedName, nestODO);
		}
		else if (list_.elementAt(i) instanceof CobolElementaryRecord)
		{
			CobolElementaryRecord type = (CobolElementaryRecord)list_.elementAt(i);
			type.walkTree(aNonRedefineList, aNonDependingList, qualifiedName, nestODO);
		}
	}

	// Adds the name of this array to the CobolRecord of the variable that 
	// defines the size of this array
	if (dependedOnItem_.size() > 0)
	{
		for (int i=0; i<aNonDependingList.size(); i++){
			CobolRecord rec = (CobolRecord)aNonDependingList.elementAt(i);
			if (sameItem((String[]) rec.qualifiedName(), dependedOnItem_)){
				rec.setVarLengthArrayName(qualifiedName_);
				break;
			}
		}
	}

   // Add this CobolRecord to the CobolRecord that is being redefined
	if ( redefinedItem_ != null )
	{
		for (int i=0; i<aNonRedefineList.size(); i++)
		{
			CobolRecord rec = (CobolRecord)aNonRedefineList.elementAt(i);
			String str = rec.name();
			int num = rec.level();
			if ( num == level_ && str.equalsIgnoreCase(redefinedItem_) )
			{
			   rec.addRedefineType(this);
			   break;
			}
		 }
	}
	else
	{
		aNonRedefineList.addElement(this);
	}     
	 
	if (nestedODO)
	{
		qualifiedName.removeElementAt(qualifiedName.size()-1);
	}
	qualifiedName.removeElementAt(qualifiedName.size()-1);
	return;
}
}
