// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<com.ibm.etools.cobol.preference.ui>>
//   (C) Copyright IBM Corp. 2002,2004 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************

package com.ibm.etools.cobol.preference.ui.typeimport;

import java.util.HashMap;
import java.util.Vector;

import org.eclipse.core.resources.IFile;
import org.eclipse.hyades.logging.events.cbe.ValidationException;
import org.eclipse.jface.wizard.IWizard;
import org.eclipse.jface.wizard.IWizardPage;
import org.eclipse.jface.wizard.Wizard;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.widgets.Composite;

import com.ibm.etools.cobol.plugin.CobolPlugin;
import com.ibm.etools.cobol.preference.ui.common.CobolPropertiesPage;
import com.ibm.etools.cobol.preference.ui.plugin.CobolPreferenceUIPlugin;
import com.ibm.etools.logging.util.Level;

public class CobolImporterPropertiesPage extends WizardPage implements IWizardPage {
	private static final String copyright = "(c) Copyright IBM Corporation 2001,2004.";

	
	private IFile cobolFile = null;
	
	private CobolPropertiesPage cobolProps;

	/**
	 * Constructor for CobolImporterPropertiesPage
	 */	
	public CobolImporterPropertiesPage(IWizard parent, String page, IFile aCobolFile) {
		super(page);
		setTitle(CobolPreferenceUIPlugin.getResource("%COBOL_IMPORT_PROPETIES"));
		setDescription(CobolPreferenceUIPlugin.getResource("%SPECIFY_PLATFORM_PROP"));
		
		setPageComplete(false);
		
	 	// Add the page to the parent wizard
		if (parent instanceof Wizard) {
			((Wizard)parent).addPage(this);
		}

		cobolFile=aCobolFile;
	}

	/**
	 * @see ScriptWizardPage#performValidate()
	 */
	protected void performValidate() throws Exception {

		/*
		 * Before invoking the importer,
		 * validate the screen fields
		 */
		Vector validationErrors = cobolProps.getValidationErrorMessages();
		if(validationErrors.size() == 0) { 
			setPageComplete(true);		
		}	
		else {
			setPageComplete(false);
			// If we set the error message our superclass overrides it and sets it
			// back to no error - throw a ValidationException instead.
			// this.setErrorMessage((String)validationErrors.get(0));
			if (((String)validationErrors.get(0)).equalsIgnoreCase(com.ibm.etools.cobol.importer.CobolResource.getString("_EXC_Invalid_codepage")))
				cobolProps.getCodePageField().setFocus();
			else
				cobolProps.getTextCurrency().setFocus();
			throw new ValidationException((String)validationErrors.get(0));
		}
		
		return;		
	}
	
	/**
	 * This method is invoked to update the page.
	 */
	public void update(Object source) {
		try {
			validatePage();
		} catch (Exception e) {
			CobolPlugin.getPlugin().writeMsg(Level.SEVERE,"*** CobolImporterPropertiesPage.update(Object): Exception = " + e.getMessage());			
		}
	}
	
	/**
	 * Validate the page.
	 */
	public boolean validatePage() {
		try {
			performValidate();
		} catch (ValidationException e) {
			setErrorMessage(e.getMessage());
			setPageComplete(false);
			return false;
		} catch (Exception e) {
			setPageComplete(false);
			CobolPlugin.getPlugin().writeMsg(Level.SEVERE,"*** CobolImporterPropertiesPage.validatePage(): Exception = " + e.getMessage());				
			return false;
		}
		setErrorMessage(null);
		return true;
	}

	public HashMap getValues() {
		return cobolProps.getValues();
	}

	public void createControl(Composite parent) {
		cobolProps = new CobolPropertiesPage(this);
		
		setControl(cobolProps.createContents(parent));
		
		cobolProps.setHelpContextIds();
			
		validatePage();
	}

	public CobolPropertiesPage getCobolPropertiesPage(){
		return cobolProps;
	}

}