// ****************************************************************
//
//   IBM Confidential
//   OCO Source Materials
//   <<PART NUMBER - 5724-B75>>
//   (C) Copyright IBM Corp. 1999, 2004 - All Rights Reserved.
//   US Government Users Restricted Rights - Use, duplication or disclosure
//   restricted by GSA ADP Schedule Contract with IBM Corp.
//
// ****************************************************************
package com.ibm.etools.marshall.util;

/**
 * This class defines the behavior for a range of double values.  This
 * class is intended to be used with the possible value construct
 * on a field.
 */

public class DoubleRange implements IRangeObject
{
	private static String copyright = "(c) Copyright IBM Corporation 1999, 2004.";
	static final long serialVersionUID = 3380398617924967024L;

	protected double lowerRange_;
	protected double upperRange_;
/**
 * Creates a new empty instance of an DoubleRange object.
 */

public DoubleRange()
{
	lowerRange_ = 0;
	upperRange_ = 0;
}
/**
 * Creates a new instance of an DoubleRange object with the specified upper
 * and lower ranges.
 * @param lowerRange The lower range.
 * @param upperRange The upper range.
 * @exception java.lang.IllegalArgumentException The upper range is less than
 * the lower range.
 */

public DoubleRange(double lowerRange, double upperRange) throws IllegalArgumentException
{
	if (upperRange < lowerRange)
		throw new IllegalArgumentException(Double.toString(upperRange));

	lowerRange_ = lowerRange;
	upperRange_ = upperRange;
}
/**
 * Creates a new object of the same class as this object. It then initializes
 * each of the new object's fields by assigning it the same value as
 * the corresponding field in this object. No constructor is called.
 * @return A new object initialized to the same state as this object.
 */

public Object clone()
{
	try
	{
		DoubleRange newType = (DoubleRange)super.clone();

		return (newType);
	}
	catch (CloneNotSupportedException ex)
	{
		throw new java.lang.InternalError(ex.getMessage());
	}
}
/**
 * This method determines if the two integer range objects are equivalent.
 * @return <code>true</code> if this range object is the same as the obj
 * argument; <code>false</code> otherwise.
 * @param obj The reference object with which to compare.
 */

public boolean equals (Object obj)
{
	if (obj == null)
		return (false);

	if (this == obj)
		return (true);

	if (!(obj instanceof DoubleRange))
		return (false);

	DoubleRange tmpRange = (DoubleRange)obj;

	if (lowerRange_ != tmpRange.lowerRange_)
		return (false);

	if (upperRange_ != tmpRange.upperRange_)
		return (false);

	return (true);
}
/**
 * Returns the lower range, or bounds, of the range object as a
 * java.lang.Double object.
 * @return The lower range, or bounds, of the range object.
 */

public Object getLowerRange()
{
	return (new Double(lowerRange_));
}
/**
 * Returns the upper range, or bounds, of the range object as a
 * java.lang.Double object.
 * @return The upper range, or bounds, of the range object.
 */

public Object getUpperRange()
{
	return (new Double(upperRange_));
}
/**
 * Tests whether the specified value lies within the specifed upper and lower
 * range.
 * @return <code>true</code> if the specified value lies within the upper
 * and lower range; <code>false</code> otherwise.
 * @param lowerRange The lower range limit.
 * @param upperRange The upper range limit.
 * @param value The value to compare against.
 * @exception java.lang.IllegalArgumentException The upper range is less than
 * the lower range.
 */

public static boolean isInRange (double lowerRange, double upperRange, double value)
	throws IllegalArgumentException
{
	if (upperRange < lowerRange)
		throw new IllegalArgumentException(Double.toString(upperRange));

	if ((value >= lowerRange) && (value <= upperRange))
		return (true);

	return (false);
}
/**
 * Tests whether the specified value lies within the upper and lower range
 * set on the range object.
 * @return <code>true</code> if the specified value lies within the upper
 * and lower range; <code>false</code> otherwise.
 * @param value The value to compare against.  Must be a java.lang.Double object.
 */

public boolean isInRange (Object value)
{
	if (!(value instanceof Double))
		return (false);

	double doubleVal = ((Double)value).doubleValue();

	return (isInRange (lowerRange_, upperRange_, doubleVal));
}
/**
 * Sets the lower range, or bounds, of the range object.
 * @param value The lower range value.  Must be a java.lang.Double object.
 * @exception IllegalArgumentException The value specified is not valid for
 * this range object.
 */

public void setLowerRange (Object value) throws IllegalArgumentException
{
	if (!(value instanceof Double))
		throw new IllegalArgumentException(value.toString());

	lowerRange_ = ((Double)value).doubleValue();

	return;
}
/**
 * Sets the upper range, or bounds, of the range object.
 * @param value The upper range value.  Must be a java.lang.Double object.
 * @exception IllegalArgumentException The value specified is not valid for
 * this range object.
 */

public void setUpperRange (Object value) throws IllegalArgumentException
{
	if (!(value instanceof Double))
		throw new IllegalArgumentException(value.toString());

	upperRange_ = ((Double)value).doubleValue();

	return;
}
}
